var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import * as React from 'react';
import { render, screen } from '@testing-library/react';
import HttpClient from '../classes/HttpClient';
import axios from 'axios';
import { getRequestData } from './mocked.data';
import ApiClient from '../components/ApiClient';
import DummyConsumer from './dummies/ApiConsumer';
var endpoints = {
    user: {
        list: '/application/user',
        edit: '/application/user/:id:',
        save: '/application/user',
        delete: '/application/user/:id:'
    },
    settings: {
        categories: {
            list: '/application/category',
            edit: '/application/category/:id:'
        }
    }
};
var server = 'http://api.server.com';
describe('Check the http client', function () {
    var Instance = new HttpClient({
        endpoints: endpoints,
        server: server
    });
    it('Checking the endpoints assignation', function () {
        expect(Instance.getEndpoints()).toEqual(endpoints);
        expect(Instance.getServer()).toEqual(server);
    });
    it('Checking default headers', function () {
        var headersMock = {
            Accept: 'application/json',
            'Content-Type': 'application/json'
        };
        expect(Instance.getHeaders()).toEqual(headersMock);
    });
    it('Checking the log: ', function () {
        expect(Instance.getLog()).toEqual([]);
    });
    it('Checking the resolve path:', function () {
        expect(Instance.resolvePath('user.list')).toEqual('/application/user');
        expect(Instance.resolvePath('settings.categories.list')).toEqual('/application/category');
        expect(Instance.resolvePath('user.edit', {
            replace: {
                id: 2
            }
        })).toEqual('/application/user/2');
        expect(Instance.resolvePath('settings.categories.edit', {
            replace: {
                id: 5
            }
        })).toEqual('/application/category/5');
    });
});
describe('Making http requests: ', function () {
    var Instance = new HttpClient({
        endpoints: endpoints,
        server: server
    });
    it('Checking do request (get): ', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, data, method, _c, firstItem;
        return __generator(this, function (_d) {
            switch (_d.label) {
                case 0:
                    mock = jest.spyOn(axios, 'get');
                    // @ts-ignore
                    mock.mockReturnValueOnce(getRequestData);
                    return [4 /*yield*/, Instance.doGet('user.list', { debug: true })];
                case 1:
                    _a = _d.sent(), _b = _a.data, data = _b === void 0 ? [] : _b, method = _a.method;
                    expect(Array.isArray(data)).toBeTruthy();
                    _c = data[0], firstItem = _c === void 0 ? {} : _c;
                    expect(method).toEqual('get');
                    expect(firstItem).toEqual({ id: 1, userName: 'Usuario 1' });
                    return [2 /*return*/];
            }
        });
    }); });
    it('Checking do post: ', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, data, url, body, method;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    mock = jest.spyOn(axios, 'post');
                    // @ts-ignore
                    mock.mockReturnValueOnce({
                        // @ts-ignore
                        saved: true
                    });
                    return [4 /*yield*/, Instance.doPost('user.save', {
                            debug: true,
                            data: {
                                user: 1
                            }
                        })];
                case 1:
                    _a = _c.sent(), _b = _a.data, data = _b === void 0 ? {} : _b, url = _a.url, body = _a.body, method = _a.method;
                    expect(data.saved).toBeTruthy();
                    expect(method).toEqual('post');
                    expect(body).toEqual({
                        user: 1
                    });
                    expect(url).toEqual(server + '/application/user');
                    return [2 /*return*/];
            }
        });
    }); });
    it('Checking do patch: ', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, data, url, body, method;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    mock = jest.spyOn(axios, 'patch');
                    // @ts-ignore
                    mock.mockReturnValueOnce({
                        // @ts-ignore
                        saved: true
                    });
                    return [4 /*yield*/, Instance.doPatch('user.edit', {
                            debug: true,
                            replace: {
                                id: 1
                            },
                            data: {
                                user: 1
                            }
                        })];
                case 1:
                    _a = _c.sent(), _b = _a.data, data = _b === void 0 ? {} : _b, url = _a.url, body = _a.body, method = _a.method;
                    expect(data.saved).toBeTruthy();
                    expect(method).toEqual('patch');
                    expect(body).toEqual({
                        user: 1
                    });
                    expect(url).toEqual(server + '/application/user/1');
                    return [2 /*return*/];
            }
        });
    }); });
    it('Checking do put: ', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, data, url, body, method;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    mock = jest.spyOn(axios, 'put');
                    // @ts-ignore
                    mock.mockReturnValueOnce({
                        // @ts-ignore
                        updated: true
                    });
                    return [4 /*yield*/, Instance.doPut('user.edit', {
                            debug: true,
                            replace: {
                                id: 1
                            },
                            data: {
                                user: 1
                            }
                        })];
                case 1:
                    _a = _c.sent(), _b = _a.data, data = _b === void 0 ? {} : _b, url = _a.url, body = _a.body, method = _a.method;
                    expect(data.updated).toBeTruthy();
                    expect(method).toEqual('put');
                    expect(body).toEqual({
                        user: 1
                    });
                    expect(url).toEqual(server + '/application/user/1');
                    return [2 /*return*/];
            }
        });
    }); });
    it('Checking do delete: ', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, data, url, method;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    mock = jest.spyOn(axios, 'delete');
                    // @ts-ignore
                    mock.mockReturnValueOnce({
                        // @ts-ignore
                        deleted: true
                    });
                    return [4 /*yield*/, Instance.doDelete('user.delete', {
                            debug: true,
                            replace: {
                                id: 1
                            }
                        })];
                case 1:
                    _a = _c.sent(), _b = _a.data, data = _b === void 0 ? {} : _b, url = _a.url, method = _a.method;
                    expect(data.deleted).toBeTruthy();
                    expect(method).toEqual('delete');
                    expect(url).toEqual(server + '/application/user/1');
                    return [2 /*return*/];
            }
        });
    }); });
});
describe('Testing the renders: ', function () {
    var provider = (React.createElement(ApiClient, { config: { endpoints: endpoints, server: server } },
        React.createElement(DummyConsumer, null)));
    beforeEach(function () {
        return render(provider);
    });
    it('Should render context', function () { return __awaiter(void 0, void 0, void 0, function () {
        var mock, _a, _b, _c, _d, _e, _f;
        return __generator(this, function (_g) {
            switch (_g.label) {
                case 0:
                    mock = jest.spyOn(axios, 'get');
                    // @ts-ignore
                    mock.mockReturnValueOnce(getRequestData);
                    _a = expect;
                    return [4 /*yield*/, screen.findByText(/Dummy for api/)];
                case 1:
                    _a.apply(void 0, [_g.sent()]).toBeTruthy();
                    _b = expect;
                    return [4 /*yield*/, screen.findByText(/Get correctly/i)];
                case 2:
                    _b.apply(void 0, [_g.sent()]).toBeTruthy();
                    _c = expect;
                    return [4 /*yield*/, screen.findByText(/Post correctly/i)];
                case 3:
                    _c.apply(void 0, [_g.sent()]).toBeTruthy();
                    _d = expect;
                    return [4 /*yield*/, screen.findByText(/Patch correctly/i)];
                case 4:
                    _d.apply(void 0, [_g.sent()]).toBeTruthy();
                    _e = expect;
                    return [4 /*yield*/, screen.findByText(/Delete correctly/i)];
                case 5:
                    _e.apply(void 0, [_g.sent()]).toBeTruthy();
                    _f = expect;
                    return [4 /*yield*/, screen.findByText(/Put correctly/i)];
                case 6:
                    _f.apply(void 0, [_g.sent()]).toBeTruthy();
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=HttpClient.test.js.map